<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 08/13/2011 *
 * ===================                          Last change: 08/13/2011 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-config_network_types.php                    *
 * -------------------------------------------------------------------- *
 * Short description : Handler types configuration                      *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Werbe-Handler-Konfiguration                      *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2015 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isAdmin())) {
	die();
} // END - if

// Add description as navigation point
addYouAreHereLink('admin', __FILE__);

// By default we should display list/add new forms
$GLOBALS['network_display'] = TRUE;

// Handle form here
doNetworkHandleForm();

// Display forms?
if ($GLOBALS['network_display'] === FALSE) {
	// Abort here
	return;
} // END - if

// Is there a network selected?
if (isGetRequestElementSet('network_id')) {
	// Set current network id
	setCurrentNetworkId(getRequestElement('network_id'));

	// Is a network type handler selected?
	if (isGetRequestElementSet('network_type_id')) {
		// Load data for given network
		$result = sqlQueryEscaped('SELECT
	`t`.`network_id`,
	`t`.`network_type_id`,
	`t`.`network_type_handler`,
	`t`.`network_type_reload_time_unit`,
	`d`.`network_active`,
	NULL AS `network_data_id`,
	NULL AS `network_max_reload_time`,
	NULL AS `network_min_waiting_time`,
	NULL AS `network_max_waiting_time`,
	NULL AS `network_min_remain_budget`,
	NULL AS `network_min_remain_clicks`,
	NULL AS `network_min_payment`,
	NULL AS `network_allow_erotic`,
	NULL AS `network_media_size`,
	NULL AS `network_media_output`
FROM
	`{?_MYSQL_PREFIX?}_network_types` AS `t`
INNER JOIN
	`{?_MYSQL_PREFIX?}_network_data` AS `d`
ON
	d.network_id=t.network_id
WHERE
	`t`.`network_id`=%s AND
	`t`.`network_type_id`=%s
LIMIT 1',
			array(
				bigintval(getRequestElement('network_id')),
				bigintval(getRequestElement('network_type_id'))
			), __FUNCTION__, __LINE__);

		// Is there a record?
		if (sqlNumRows($result) == 1) {
			// Load it
			$content = sqlFetchArray($result);

			// Is the network active?
			if (($content['network_active'] == 'N') && (!isAdminsExpertWarningEnabled()) && (!isDebugModeEnabled())) {
				// Not active
				displayMessage('{--ADMIN_NETWORK_NOT_ACTIVE--}');
				return;
			} // END - if

			// Check for network type configuration
			$result_config = sqlQueryEscaped('SELECT
	`network_data_id`,
	`network_max_reload_time`,
	`network_min_waiting_time`,
	`network_max_waiting_time`,
	`network_min_remain_budget`,
	`network_min_remain_clicks`,
	`network_min_payment`,
	`network_allow_erotic`,
	`network_media_size`,
	`network_media_output`
FROM
	`{?_MYSQL_PREFIX?}_network_handler_config`
WHERE
	`network_id`=%s AND
	`network_type_id`=%s
LIMIT 1',
				array(
					bigintval(getRequestElement('network_id')),
					bigintval($content['network_type_id'])
				), __FUNCTION__, __LINE__);

			// Use template for adding
			$templateName = 'admin_add_config_network_type_form';

			// Do we also have configuration?
			if (sqlNumRows($result_config) == 1) {
				// Load as well and merge it
				$content = merge_array($content, sqlFetchArray($result_config));

				// Use template for editing
				$templateName = 'admin_edit_config_network_type_form';
			} // END - if

			// Free result
			sqlFreeResult($result_config);

			// "Translate" some values
			$content['network_max_reload_time']  = createTimeSelections($content['network_max_reload_time'], 'network_max_reload_time', 'WDhms');

			// Load template
			loadTemplate($templateName, FALSE, $content);

			// Abort here
			return;
		} else {
			// No entry found
			displayMessage('{%message,ADMIN_ADD_CONFIG_NETWORK_HANDLER_TYPE_404=' . bigintval(getRequestElement('network_id')) . '/' . bigintval(getRequestElement('network_type_id')) . '%}');
		} // END - if

		// Free result
		sqlFreeResult($result);
	} // END - if

	// Get all type handlers
	$result = sqlQueryEscaped('SELECT
	`network_id`,
	`network_type_id`,
	`network_type_handler`,
	`network_type_reload_time_unit`
FROM
	`{?_MYSQL_PREFIX?}_network_types`
WHERE
	`network_id`=%s
ORDER BY
	`network_type_handler` ASC',
		array(
			bigintval(getRequestElement('network_id'))
		), __FUNCTION__, __LINE__);

	// Are there entries left?
	if (!ifSqlHasZeroNumRows($result)) {
		// Init row output
		$OUT = '';

		// List all entries
		while ($content = sqlFetchArray($result)) {
			// Check if config entry is there
			$result_config = sqlQueryEscaped('SELECT
	`network_data_id`,
	`network_max_reload_time`,
	`network_min_waiting_time`,
	`network_max_waiting_time`,
	`network_min_remain_budget`,
	`network_min_remain_clicks`,
	`network_min_payment`,
	`network_allow_erotic`,
	`network_media_size`,
	`network_media_output`
FROM
	`{?_MYSQL_PREFIX?}_network_handler_config`
WHERE
	`network_id`=%s AND
	`network_type_id`=%s
LIMIT 1',
				array(
					bigintval(getRequestElement('network_id')),
					bigintval($content['network_type_id'])
				), __FUNCTION__, __LINE__);

			// Is there an entry?
			if (sqlNumRows($result_config) == 1) {
				// Load this data as well
				$content = merge_array($content, sqlFetchArray($result_config));

				// Add it with extra template
				$content['network_type_config_content'] = loadTemplate('admin_show_config_network_type', TRUE, $content);
			} else {
				// No configuration found, so display form
				$content['network_type_config_content'] = loadTemplate('admin_add_config_network_type', TRUE, $content);
			}

			// Free result
			sqlFreeResult($result_config);

			// Load row template
			$OUT .= loadTemplate('admin_config_network_types_row', TRUE, $content);
		} // END - while

		// Prepare array for main template
		$content = array(
			'network_id' => bigintval(getRequestElement('network_id')),
			'rows'       => $OUT
		);

		// Load main template
		loadTemplate('admin_config_network_types', FALSE, $content);
	} else {
		// No entries found
		displayMessage('{%message,ADMIN_CONFIG_NETWORK_HANDLER_TYPES_404=' . bigintval(getRequestElement('network_id')) . '%}');
	}

	// Free result
	sqlFreeResult($result);
} else {
	// Generate network list for this script
	$OUT = generateAdminNetworkList(FALSE, TRUE, FALSE);

	// Is it not empty?
	if (!empty($OUT)) {
		// Output it
		outputHtml($OUT);
	} else {
		// Nothing configured yet
		displayMessage('{--ADMIN_NETWORK_QUERY_API_404--}');
	}
}

// [EOF]
?>
