<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 06/30/2011 *
 * ===================                          Last change: 06/30/2011 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-list_admins_acls.php                        *
 * -------------------------------------------------------------------- *
 * Short description : List admin access control lines (ACLs)           *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Auflisten von Zugriffskontrollzeilen (ACLs)      *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2015 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isAdmin())) {
	die();
} // END - if

// Add description as navigation point
addYouAreHereLink('admin', __FILE__);

if ((isFormSent('edit')) && (ifPostContainsSelections())) {
	// Edit ACLs
	$OUT = '';
	foreach (postRequestElement('sel') as $id => $selected) {
		// Load data for the id
		$result = sqlQueryEscaped("SELECT `id`, `admin_id`, `action_menu`, `what_menu`, `access_mode` FROM `{?_MYSQL_PREFIX?}_admins_acls` WHERE `id`=%s LIMIT 1",
			array(bigintval($id)), __FILE__, __LINE__);

		// Load all data
		$content = sqlFetchArray($result);

		// Free result
		sqlFreeResult($result);

		// Prepare data for the row template
		$content = array(
			'id'               => $content['id'],
			'admins_selection' => generateOptions('admins', 'id', 'login', $content['admin_id'], 'default_acl'),
			'action_selection' => adminMenuSelectionBox_DEPRECATED('action', $content['action_menu'], $content['id']),
			'what_selection'   => adminMenuSelectionBox_DEPRECATED('what', $content['what_menu'], $content['id']),
		);

		// Load row template
		$OUT .= loadTemplate('admin_edit_admins_acls_row', TRUE, $content);
	} // END - foreach

	// Load main template
	loadTemplate('admin_edit_admins_acls', FALSE, $OUT);
} elseif ((isFormSent('do_edit')) && (ifPostContainsSelections())) {
	// Change entries
	foreach (postRequestElement('sel') as $id => $selected) {
		// Secure id
		$id = bigintval($id);

		// Update entries
		sqlQueryEscaped("UPDATE
	`{?_MYSQL_PREFIX?}_admins_acls`
SET
	`admin_id`=%s,
	`action_menu`='%s',
	`what_menu`='%s',
	`access_mode`='%s'
WHERE
	`id`=%s
LIMIT 1",
			array(
				postRequestElement('admin', $id),
				postRequestElement('action_menu', $id),
				postRequestElement('what_menu', $id),
				postRequestElement('access_mode', $id),
				$id
			),__FILE__, __LINE__);
	} // END - foreach

	// Update cache when installed
	rebuildCache('admin_acls', 'admin_acls');

	// Entries changed
	displayMessage('{--ADMIN_ADMINS_ENTRIES_CHANGED--}');
} elseif ((isFormSent('delete')) && (ifPostContainsSelections())) {
	// Delete ACLs
	$OUT = '';
	foreach (postRequestElement('sel') as $id => $selected) {
		// Load data for the id
		$result = sqlQueryEscaped("SELECT `id`, `admin_id`, `action_menu`, `what_menu`, `access_mode` FROM `{?_MYSQL_PREFIX?}_admins_acls` WHERE `id`=%s LIMIT 1",
			array(bigintval($id)), __FILE__, __LINE__);
		$content = sqlFetchArray($result);
		sqlFreeResult($result);

		// Get admin mode
		$content['access_mode'] = '{--ADMIN_ADMINS_ACCESS_MODE_' . strtoupper($content['access_mode']) . '--}';

		// Load row template and switch colors
		$OUT .= loadTemplate('admin_delete_admins_acls_row', TRUE, $content);
	} // END - foreach

	// Load main template
	loadTemplate('admin_delete_admins_acls', FALSE, $OUT);
} elseif ((isFormSent('do_delete')) && (ifPostContainsSelections())) {
	// Remove entries
	// @TODO Rewrite this to filter 'run_sqls'
	foreach (postRequestElement('sel') as $id => $selected) {
		sqlQueryEscaped("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_admins_acls` WHERE `id`=%s LIMIT 1",
			array(bigintval($id)),__FILE__, __LINE__);
	} // END - foreach

	// Update cache when installed
	rebuildCache('admin_acls', 'admin_acls');

	// Entries deleted
	displayMessage('{--ADMIN_ADMINS_ENTRIES_DELETED--}');
} elseif (isFormSent('add')) {
	// Check if everything is fine...
	$mode = getAdminDefaultAcl(bigintval(postRequestElement('admin_id')));

	// Default ACL is false
	$ACL = FALSE;
	if (isPostRequestElementSet('what_menu')) {
		// Check parent ACL
		$ACL = isAdminsAllowedByAcl(getActionFromModuleWhat('admin', postRequestElement('what_menu')), '');
	} // END - if

	if (($mode != postRequestElement('do')) || (($ACL === TRUE) && (postRequestElement('do') == 'deny'))) {
		// Mode is fine
		$BOTH = ((isPostRequestElementSet('action_menu')) && (isPostRequestElementSet('what_menu')) && (postRequestElement('action_menu') != '') && (postRequestElement('what_menu') != ''));

		// Check if one has been selected
		if ((((isPostRequestElementSet('action_menu')) && (postRequestElement('action_menu') != '')) || ((isPostRequestElementSet('what_menu')) && (postRequestElement('what_menu') != ''))) && ($BOTH === FALSE)) {
			// Main or sub menu selected
			$result = sqlQueryEscaped("SELECT `id` FROM `{?_MYSQL_PREFIX?}_admins_acls` WHERE `admin_id`=%s AND `action_menu`='%s' AND `what_menu`='%s' LIMIT 1",
				array(
					bigintval(postRequestElement('admin_id')),
					postRequestElement('action_menu'),
					postRequestElement('what_menu')
				), __FILE__, __LINE__);
			if (ifSqlHasZeroNumRows($result)) {
				// Finally add the new ACL
				sqlQueryEscaped("INSERT INTO `{?_MYSQL_PREFIX?}_admins_acls` (
	`admin_id`,
	`action_menu`,
	`what_menu`,
	`access_mode`
) VALUES (
	%s,
	'%s',
	'%s',
	'%s'
)",
				array(
					bigintval(postRequestElement('admin_id')),
					postRequestElement('action_menu'),
					postRequestElement('what_menu'),
					postRequestElement('do')
				), __FILE__, __LINE__);
				$content = '{--ADMIN_ADMINS_ACL_SAVED--}';

				// Update cache when installed
				rebuildCache('admin_acls', 'admin_acls');
			} else {
				// ACL does already exist!
				$content = '{--ADMIN_ADMINS_ACL_ALREADY_ADDED--}';
			}

			// Free memory
			sqlFreeResult($result);
		} else {
			// No menu selected makes also no sence...
			$content = '{--ADMIN_ADMINS_SELECT_ACTION_WHAT--}';
		}
	} else {
		// Same mode makes no sence...
		$content = '{--ADMIN_ADMINS_SAME_MODE_SELECTED--}';
	}

	// Display message
	displayMessage($content);
} else {
	// List all ACLs
	$result = sqlQuery('SELECT
	`id`,
	`admin_id`,
	`action_menu`,
	`what_menu`,
	`access_mode`
FROM
	`{?_MYSQL_PREFIX?}_admins_acls`
ORDER BY
	`admin_id` ASC,
	`id` ASC', __FILE__, __LINE__);

	// Entries found?
	if (!ifSqlHasZeroNumRows($result)) {
		// List ACLs
		$OUT = '';
		while ($content = sqlFetchArray($result)) {
			// Generate mode string
			$content['access_mode'] = '{--ADMIN_ADMINS_ACCESS_MODE_' . strtoupper($content['access_mode']) . '--}';

			// Load row template and switch colors
			$OUT .= loadTemplate('admin_list_admins_acls_row', TRUE, $content);
		} // END - while

		// Free memory
		sqlFreeResult($result);

		// Load main template
		loadTemplate('admin_list_admins_acls', FALSE, $OUT);
	} // END - if

	// Prepare some constants for the template
	$content['admins_selection'] = generateOptions('admins', 'id', 'login', '', 'default_acl');
	$content['action_selection'] = adminMenuSelectionBox_DEPRECATED('action');
	$content['what_selection']   = adminMenuSelectionBox_DEPRECATED('what');

	// Load template for adding new ACL
	loadTemplate('admin_add_admins_acl', FALSE, $content);
}

// [EOF]
?>
